// This file is based on iconimports.ts in @jupyterlab/ui-components, but is manually generated.

import { LabIcon } from '@jupyterlab/ui-components';

import calendarAddOnSvgstr from '../../style/icons/calendar-add-on.svg';
import calendarMonthSvgStr from '../../style/icons/calendar-month.svg';
import eventNoteSvgstr from '../../style/icons/event-note.svg';

export const calendarAddOnIcon = new LabIcon({
  name: 'jupyterlab-scheduler:calendar-add-on',
  svgstr: calendarAddOnSvgstr
});
export const calendarMonthIcon = new LabIcon({
  name: 'jupyterlab-scheduler:calendar-month',
  svgstr: calendarMonthSvgStr
});
export const eventNoteIcon = new LabIcon({
  name: 'jupyterlab-scheduler:event-note',
  svgstr: eventNoteSvgstr
});
